.. data:: GL_ACTIVE_ATTRIBUTES

   :type: int

.. data:: GL_ACTIVE_ATTRIBUTE_MAX_LENGTH

   :type: int

.. data:: GL_ACTIVE_TEXTURE

   :type: int

.. data:: GL_ACTIVE_UNIFORMS

   :type: int

.. data:: GL_ACTIVE_UNIFORM_BLOCKS

   :type: int

.. data:: GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH

   :type: int

.. data:: GL_ACTIVE_UNIFORM_MAX_LENGTH

   :type: int

.. data:: GL_ALIASED_LINE_WIDTH_RANGE

   :type: int

.. data:: GL_ALPHA

   :type: int

.. data:: GL_ALREADY_SIGNALED

   :type: int

.. data:: GL_ALWAYS

   :type: int

.. data:: GL_AND

   :type: int

.. data:: GL_AND_INVERTED

   :type: int

.. data:: GL_AND_REVERSE

   :type: int

.. data:: GL_ANY_SAMPLES_PASSED

   :type: int

.. data:: GL_ARRAY_BUFFER

   :type: int

.. data:: GL_ARRAY_BUFFER_BINDING

   :type: int

.. data:: GL_ATTACHED_SHADERS

   :type: int

.. data:: GL_BACK

   :type: int

.. data:: GL_BACK_LEFT

   :type: int

.. data:: GL_BACK_RIGHT

   :type: int

.. data:: GL_BGR

   :type: int

.. data:: GL_BGRA

   :type: int

.. data:: GL_BGRA_INTEGER

   :type: int

.. data:: GL_BGR_INTEGER

   :type: int

.. data:: GL_BLEND

   :type: int

.. data:: GL_BLEND_DST

   :type: int

.. data:: GL_BLEND_DST_ALPHA

   :type: int

.. data:: GL_BLEND_DST_RGB

   :type: int

.. data:: GL_BLEND_EQUATION_ALPHA

   :type: int

.. data:: GL_BLEND_EQUATION_RGB

   :type: int

.. data:: GL_BLEND_SRC

   :type: int

.. data:: GL_BLEND_SRC_ALPHA

   :type: int

.. data:: GL_BLEND_SRC_RGB

   :type: int

.. data:: GL_BLUE

   :type: int

.. data:: GL_BLUE_INTEGER

   :type: int

.. data:: GL_BOOL

   :type: int

.. data:: GL_BOOL_VEC2

   :type: int

.. data:: GL_BOOL_VEC3

   :type: int

.. data:: GL_BOOL_VEC4

   :type: int

.. data:: GL_BUFFER_ACCESS

   :type: int

.. data:: GL_BUFFER_ACCESS_FLAGS

   :type: int

.. data:: GL_BUFFER_MAPPED

   :type: int

.. data:: GL_BUFFER_MAP_LENGTH

   :type: int

.. data:: GL_BUFFER_MAP_OFFSET

   :type: int

.. data:: GL_BUFFER_MAP_POINTER

   :type: int

.. data:: GL_BUFFER_SIZE

   :type: int

.. data:: GL_BUFFER_USAGE

   :type: int

.. data:: GL_BYTE

   :type: int

.. data:: GL_CCW

   :type: int

.. data:: GL_CLAMP_READ_COLOR

   :type: int

.. data:: GL_CLAMP_TO_BORDER

   :type: int

.. data:: GL_CLAMP_TO_EDGE

   :type: int

.. data:: GL_CLEAR

   :type: int

.. data:: GL_CLIP_DISTANCE0

   :type: int

.. data:: GL_CLIP_DISTANCE1

   :type: int

.. data:: GL_CLIP_DISTANCE2

   :type: int

.. data:: GL_CLIP_DISTANCE3

   :type: int

.. data:: GL_CLIP_DISTANCE4

   :type: int

.. data:: GL_CLIP_DISTANCE5

   :type: int

.. data:: GL_COLOR

   :type: int

.. data:: GL_COLOR_ATTACHMENT0

   :type: int

.. data:: GL_COLOR_ATTACHMENT1

   :type: int

.. data:: GL_COLOR_ATTACHMENT10

   :type: int

.. data:: GL_COLOR_ATTACHMENT11

   :type: int

.. data:: GL_COLOR_ATTACHMENT12

   :type: int

.. data:: GL_COLOR_ATTACHMENT13

   :type: int

.. data:: GL_COLOR_ATTACHMENT14

   :type: int

.. data:: GL_COLOR_ATTACHMENT15

   :type: int

.. data:: GL_COLOR_ATTACHMENT2

   :type: int

.. data:: GL_COLOR_ATTACHMENT3

   :type: int

.. data:: GL_COLOR_ATTACHMENT4

   :type: int

.. data:: GL_COLOR_ATTACHMENT5

   :type: int

.. data:: GL_COLOR_ATTACHMENT6

   :type: int

.. data:: GL_COLOR_ATTACHMENT7

   :type: int

.. data:: GL_COLOR_ATTACHMENT8

   :type: int

.. data:: GL_COLOR_ATTACHMENT9

   :type: int

.. data:: GL_COLOR_BUFFER_BIT

   :type: int

.. data:: GL_COLOR_CLEAR_VALUE

   :type: int

.. data:: GL_COLOR_LOGIC_OP

   :type: int

.. data:: GL_COLOR_WRITEMASK

   :type: int

.. data:: GL_COMPARE_REF_TO_TEXTURE

   :type: int

.. data:: GL_COMPILE_STATUS

   :type: int

.. data:: GL_COMPRESSED_RED

   :type: int

.. data:: GL_COMPRESSED_RED_RGTC1

   :type: int

.. data:: GL_COMPRESSED_RG

   :type: int

.. data:: GL_COMPRESSED_RGB

   :type: int

.. data:: GL_COMPRESSED_RGBA

   :type: int

.. data:: GL_COMPRESSED_RG_RGTC2

   :type: int

.. data:: GL_COMPRESSED_SIGNED_RED_RGTC1

   :type: int

.. data:: GL_COMPRESSED_SIGNED_RG_RGTC2

   :type: int

.. data:: GL_COMPRESSED_SRGB

   :type: int

.. data:: GL_COMPRESSED_SRGB_ALPHA

   :type: int

.. data:: GL_COMPRESSED_TEXTURE_FORMATS

   :type: int

.. data:: GL_CONDITION_SATISFIED

   :type: int

.. data:: GL_CONSTANT_ALPHA

   :type: int

.. data:: GL_CONSTANT_COLOR

   :type: int

.. data:: GL_CONTEXT_COMPATIBILITY_PROFILE_BIT

   :type: int

.. data:: GL_CONTEXT_CORE_PROFILE_BIT

   :type: int

.. data:: GL_CONTEXT_FLAGS

   :type: int

.. data:: GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT

   :type: int

.. data:: GL_CONTEXT_PROFILE_MASK

   :type: int

.. data:: GL_COPY

   :type: int

.. data:: GL_COPY_INVERTED

   :type: int

.. data:: GL_COPY_READ_BUFFER

   :type: int

.. data:: GL_COPY_WRITE_BUFFER

   :type: int

.. data:: GL_CULL_FACE

   :type: int

.. data:: GL_CULL_FACE_MODE

   :type: int

.. data:: GL_CURRENT_PROGRAM

   :type: int

.. data:: GL_CURRENT_QUERY

   :type: int

.. data:: GL_CURRENT_VERTEX_ATTRIB

   :type: int

.. data:: GL_CW

   :type: int

.. data:: GL_DECR

   :type: int

.. data:: GL_DECR_WRAP

   :type: int

.. data:: GL_DELETE_STATUS

   :type: int

.. data:: GL_DEPTH

   :type: int

.. data:: GL_DEPTH24_STENCIL8

   :type: int

.. data:: GL_DEPTH32F_STENCIL8

   :type: int

.. data:: GL_DEPTH_ATTACHMENT

   :type: int

.. data:: GL_DEPTH_BUFFER_BIT

   :type: int

.. data:: GL_DEPTH_CLAMP

   :type: int

.. data:: GL_DEPTH_CLEAR_VALUE

   :type: int

.. data:: GL_DEPTH_COMPONENT

   :type: int

.. data:: GL_DEPTH_COMPONENT16

   :type: int

.. data:: GL_DEPTH_COMPONENT24

   :type: int

.. data:: GL_DEPTH_COMPONENT32

   :type: int

.. data:: GL_DEPTH_COMPONENT32F

   :type: int

.. data:: GL_DEPTH_FUNC

   :type: int

.. data:: GL_DEPTH_RANGE

   :type: int

.. data:: GL_DEPTH_STENCIL

   :type: int

.. data:: GL_DEPTH_STENCIL_ATTACHMENT

   :type: int

.. data:: GL_DEPTH_TEST

   :type: int

.. data:: GL_DEPTH_WRITEMASK

   :type: int

.. data:: GL_DITHER

   :type: int

.. data:: GL_DONT_CARE

   :type: int

.. data:: GL_DOUBLE

   :type: int

.. data:: GL_DOUBLEBUFFER

   :type: int

.. data:: GL_DRAW_BUFFER

   :type: int

.. data:: GL_DRAW_BUFFER0

   :type: int

.. data:: GL_DRAW_BUFFER1

   :type: int

.. data:: GL_DRAW_BUFFER10

   :type: int

.. data:: GL_DRAW_BUFFER11

   :type: int

.. data:: GL_DRAW_BUFFER12

   :type: int

.. data:: GL_DRAW_BUFFER13

   :type: int

.. data:: GL_DRAW_BUFFER14

   :type: int

.. data:: GL_DRAW_BUFFER15

   :type: int

.. data:: GL_DRAW_BUFFER2

   :type: int

.. data:: GL_DRAW_BUFFER3

   :type: int

.. data:: GL_DRAW_BUFFER4

   :type: int

.. data:: GL_DRAW_BUFFER5

   :type: int

.. data:: GL_DRAW_BUFFER6

   :type: int

.. data:: GL_DRAW_BUFFER7

   :type: int

.. data:: GL_DRAW_BUFFER8

   :type: int

.. data:: GL_DRAW_BUFFER9

   :type: int

.. data:: GL_DRAW_FRAMEBUFFER

   :type: int

.. data:: GL_DRAW_FRAMEBUFFER_BINDING

   :type: int

.. data:: GL_DST_ALPHA

   :type: int

.. data:: GL_DST_COLOR

   :type: int

.. data:: GL_DYNAMIC_COPY

   :type: int

.. data:: GL_DYNAMIC_DRAW

   :type: int

.. data:: GL_DYNAMIC_READ

   :type: int

.. data:: GL_ELEMENT_ARRAY_BUFFER

   :type: int

.. data:: GL_ELEMENT_ARRAY_BUFFER_BINDING

   :type: int

.. data:: GL_EQUAL

   :type: int

.. data:: GL_EQUIV

   :type: int

.. data:: GL_EXTENSIONS

   :type: int

.. data:: GL_FALSE

   :type: int

.. data:: GL_FASTEST

   :type: int

.. data:: GL_FILL

   :type: int

.. data:: GL_FIRST_VERTEX_CONVENTION

   :type: int

.. data:: GL_FIXED_ONLY

   :type: int

.. data:: GL_FLOAT

   :type: int

.. data:: GL_FLOAT_32_UNSIGNED_INT_24_8_REV

   :type: int

.. data:: GL_FLOAT_MAT2

   :type: int

.. data:: GL_FLOAT_MAT2x3

   :type: int

.. data:: GL_FLOAT_MAT2x4

   :type: int

.. data:: GL_FLOAT_MAT3

   :type: int

.. data:: GL_FLOAT_MAT3x2

   :type: int

.. data:: GL_FLOAT_MAT3x4

   :type: int

.. data:: GL_FLOAT_MAT4

   :type: int

.. data:: GL_FLOAT_MAT4x2

   :type: int

.. data:: GL_FLOAT_MAT4x3

   :type: int

.. data:: GL_FLOAT_VEC2

   :type: int

.. data:: GL_FLOAT_VEC3

   :type: int

.. data:: GL_FLOAT_VEC4

   :type: int

.. data:: GL_FRAGMENT_SHADER

   :type: int

.. data:: GL_FRAGMENT_SHADER_DERIVATIVE_HINT

   :type: int

.. data:: GL_FRAMEBUFFER

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_LAYERED

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER

   :type: int

.. data:: GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL

   :type: int

.. data:: GL_FRAMEBUFFER_BINDING

   :type: int

.. data:: GL_FRAMEBUFFER_COMPLETE

   :type: int

.. data:: GL_FRAMEBUFFER_DEFAULT

   :type: int

.. data:: GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT

   :type: int

.. data:: GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER

   :type: int

.. data:: GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS

   :type: int

.. data:: GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT

   :type: int

.. data:: GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE

   :type: int

.. data:: GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER

   :type: int

.. data:: GL_FRAMEBUFFER_SRGB

   :type: int

.. data:: GL_FRAMEBUFFER_UNDEFINED

   :type: int

.. data:: GL_FRAMEBUFFER_UNSUPPORTED

   :type: int

.. data:: GL_FRONT

   :type: int

.. data:: GL_FRONT_AND_BACK

   :type: int

.. data:: GL_FRONT_FACE

   :type: int

.. data:: GL_FRONT_LEFT

   :type: int

.. data:: GL_FRONT_RIGHT

   :type: int

.. data:: GL_FUNC_ADD

   :type: int

.. data:: GL_FUNC_REVERSE_SUBTRACT

   :type: int

.. data:: GL_FUNC_SUBTRACT

   :type: int

.. data:: GL_GEOMETRY_INPUT_TYPE

   :type: int

.. data:: GL_GEOMETRY_OUTPUT_TYPE

   :type: int

.. data:: GL_GEOMETRY_SHADER

   :type: int

.. data:: GL_GEOMETRY_VERTICES_OUT

   :type: int

.. data:: GL_GEQUAL

   :type: int

.. data:: GL_GREATER

   :type: int

.. data:: GL_GREEN

   :type: int

.. data:: GL_GREEN_INTEGER

   :type: int

.. data:: GL_HALF_FLOAT

   :type: int

.. data:: GL_INCR

   :type: int

.. data:: GL_INCR_WRAP

   :type: int

.. data:: GL_INDEX

   :type: int

.. data:: GL_INFO_LOG_LENGTH

   :type: int

.. data:: GL_INT

   :type: int

.. data:: GL_INTERLEAVED_ATTRIBS

   :type: int

.. data:: GL_INT_2_10_10_10_REV

   :type: int

.. data:: GL_INT_SAMPLER_1D

   :type: int

.. data:: GL_INT_SAMPLER_1D_ARRAY

   :type: int

.. data:: GL_INT_SAMPLER_2D

   :type: int

.. data:: GL_INT_SAMPLER_2D_ARRAY

   :type: int

.. data:: GL_INT_SAMPLER_2D_MULTISAMPLE

   :type: int

.. data:: GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY

   :type: int

.. data:: GL_INT_SAMPLER_2D_RECT

   :type: int

.. data:: GL_INT_SAMPLER_3D

   :type: int

.. data:: GL_INT_SAMPLER_BUFFER

   :type: int

.. data:: GL_INT_SAMPLER_CUBE

   :type: int

.. data:: GL_INT_VEC2

   :type: int

.. data:: GL_INT_VEC3

   :type: int

.. data:: GL_INT_VEC4

   :type: int

.. data:: GL_INVALID_ENUM

   :type: int

.. data:: GL_INVALID_FRAMEBUFFER_OPERATION

   :type: int

.. data:: GL_INVALID_INDEX

   :type: int

.. data:: GL_INVALID_OPERATION

   :type: int

.. data:: GL_INVALID_VALUE

   :type: int

.. data:: GL_INVERT

   :type: int

.. data:: GL_KEEP

   :type: int

.. data:: GL_LAST_VERTEX_CONVENTION

   :type: int

.. data:: GL_LEFT

   :type: int

.. data:: GL_LEQUAL

   :type: int

.. data:: GL_LESS

   :type: int

.. data:: GL_LINE

   :type: int

.. data:: GL_LINEAR

   :type: int

.. data:: GL_LINEAR_MIPMAP_LINEAR

   :type: int

.. data:: GL_LINEAR_MIPMAP_NEAREST

   :type: int

.. data:: GL_LINES

   :type: int

.. data:: GL_LINES_ADJACENCY

   :type: int

.. data:: GL_LINE_LOOP

   :type: int

.. data:: GL_LINE_SMOOTH

   :type: int

.. data:: GL_LINE_SMOOTH_HINT

   :type: int

.. data:: GL_LINE_STRIP

   :type: int

.. data:: GL_LINE_STRIP_ADJACENCY

   :type: int

.. data:: GL_LINE_WIDTH

   :type: int

.. data:: GL_LINE_WIDTH_GRANULARITY

   :type: int

.. data:: GL_LINE_WIDTH_RANGE

   :type: int

.. data:: GL_LINK_STATUS

   :type: int

.. data:: GL_LOGIC_OP_MODE

   :type: int

.. data:: GL_LOWER_LEFT

   :type: int

.. data:: GL_MAJOR_VERSION

   :type: int

.. data:: GL_MAP_FLUSH_EXPLICIT_BIT

   :type: int

.. data:: GL_MAP_INVALIDATE_BUFFER_BIT

   :type: int

.. data:: GL_MAP_INVALIDATE_RANGE_BIT

   :type: int

.. data:: GL_MAP_READ_BIT

   :type: int

.. data:: GL_MAP_UNSYNCHRONIZED_BIT

   :type: int

.. data:: GL_MAP_WRITE_BIT

   :type: int

.. data:: GL_MAX

   :type: int

.. data:: GL_MAX_3D_TEXTURE_SIZE

   :type: int

.. data:: GL_MAX_ARRAY_TEXTURE_LAYERS

   :type: int

.. data:: GL_MAX_CLIP_DISTANCES

   :type: int

.. data:: GL_MAX_COLOR_ATTACHMENTS

   :type: int

.. data:: GL_MAX_COLOR_TEXTURE_SAMPLES

   :type: int

.. data:: GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS

   :type: int

.. data:: GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS

   :type: int

.. data:: GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS

   :type: int

.. data:: GL_MAX_COMBINED_UNIFORM_BLOCKS

   :type: int

.. data:: GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS

   :type: int

.. data:: GL_MAX_CUBE_MAP_TEXTURE_SIZE

   :type: int

.. data:: GL_MAX_DEPTH_TEXTURE_SAMPLES

   :type: int

.. data:: GL_MAX_DRAW_BUFFERS

   :type: int

.. data:: GL_MAX_DUAL_SOURCE_DRAW_BUFFERS

   :type: int

.. data:: GL_MAX_ELEMENTS_INDICES

   :type: int

.. data:: GL_MAX_ELEMENTS_VERTICES

   :type: int

.. data:: GL_MAX_FRAGMENT_INPUT_COMPONENTS

   :type: int

.. data:: GL_MAX_FRAGMENT_UNIFORM_BLOCKS

   :type: int

.. data:: GL_MAX_FRAGMENT_UNIFORM_COMPONENTS

   :type: int

.. data:: GL_MAX_GEOMETRY_INPUT_COMPONENTS

   :type: int

.. data:: GL_MAX_GEOMETRY_OUTPUT_COMPONENTS

   :type: int

.. data:: GL_MAX_GEOMETRY_OUTPUT_VERTICES

   :type: int

.. data:: GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS

   :type: int

.. data:: GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS

   :type: int

.. data:: GL_MAX_GEOMETRY_UNIFORM_BLOCKS

   :type: int

.. data:: GL_MAX_GEOMETRY_UNIFORM_COMPONENTS

   :type: int

.. data:: GL_MAX_INTEGER_SAMPLES

   :type: int

.. data:: GL_MAX_PROGRAM_TEXEL_OFFSET

   :type: int

.. data:: GL_MAX_RECTANGLE_TEXTURE_SIZE

   :type: int

.. data:: GL_MAX_RENDERBUFFER_SIZE

   :type: int

.. data:: GL_MAX_SAMPLES

   :type: int

.. data:: GL_MAX_SAMPLE_MASK_WORDS

   :type: int

.. data:: GL_MAX_SERVER_WAIT_TIMEOUT

   :type: int

.. data:: GL_MAX_TEXTURE_BUFFER_SIZE

   :type: int

.. data:: GL_MAX_TEXTURE_IMAGE_UNITS

   :type: int

.. data:: GL_MAX_TEXTURE_LOD_BIAS

   :type: int

.. data:: GL_MAX_TEXTURE_SIZE

   :type: int

.. data:: GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS

   :type: int

.. data:: GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS

   :type: int

.. data:: GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS

   :type: int

.. data:: GL_MAX_UNIFORM_BLOCK_SIZE

   :type: int

.. data:: GL_MAX_UNIFORM_BUFFER_BINDINGS

   :type: int

.. data:: GL_MAX_VARYING_COMPONENTS

   :type: int

.. data:: GL_MAX_VARYING_FLOATS

   :type: int

.. data:: GL_MAX_VERTEX_ATTRIBS

   :type: int

.. data:: GL_MAX_VERTEX_OUTPUT_COMPONENTS

   :type: int

.. data:: GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS

   :type: int

.. data:: GL_MAX_VERTEX_UNIFORM_BLOCKS

   :type: int

.. data:: GL_MAX_VERTEX_UNIFORM_COMPONENTS

   :type: int

.. data:: GL_MAX_VIEWPORT_DIMS

   :type: int

.. data:: GL_MIN

   :type: int

.. data:: GL_MINOR_VERSION

   :type: int

.. data:: GL_MIN_PROGRAM_TEXEL_OFFSET

   :type: int

.. data:: GL_MIRRORED_REPEAT

   :type: int

.. data:: GL_MULTISAMPLE

   :type: int

.. data:: GL_NAND

   :type: int

.. data:: GL_NEAREST

   :type: int

.. data:: GL_NEAREST_MIPMAP_LINEAR

   :type: int

.. data:: GL_NEAREST_MIPMAP_NEAREST

   :type: int

.. data:: GL_NEVER

   :type: int

.. data:: GL_NICEST

   :type: int

.. data:: GL_NONE

   :type: int

.. data:: GL_NOOP

   :type: int

.. data:: GL_NOR

   :type: int

.. data:: GL_NOTEQUAL

   :type: int

.. data:: GL_NO_ERROR

   :type: int

.. data:: GL_NUM_COMPRESSED_TEXTURE_FORMATS

   :type: int

.. data:: GL_NUM_EXTENSIONS

   :type: int

.. data:: GL_OBJECT_TYPE

   :type: int

.. data:: GL_ONE

   :type: int

.. data:: GL_ONE_MINUS_CONSTANT_ALPHA

   :type: int

.. data:: GL_ONE_MINUS_CONSTANT_COLOR

   :type: int

.. data:: GL_ONE_MINUS_DST_ALPHA

   :type: int

.. data:: GL_ONE_MINUS_DST_COLOR

   :type: int

.. data:: GL_ONE_MINUS_SRC1_ALPHA

   :type: int

.. data:: GL_ONE_MINUS_SRC1_COLOR

   :type: int

.. data:: GL_ONE_MINUS_SRC_ALPHA

   :type: int

.. data:: GL_ONE_MINUS_SRC_COLOR

   :type: int

.. data:: GL_OR

   :type: int

.. data:: GL_OR_INVERTED

   :type: int

.. data:: GL_OR_REVERSE

   :type: int

.. data:: GL_OUT_OF_MEMORY

   :type: int

.. data:: GL_PACK_ALIGNMENT

   :type: int

.. data:: GL_PACK_IMAGE_HEIGHT

   :type: int

.. data:: GL_PACK_LSB_FIRST

   :type: int

.. data:: GL_PACK_ROW_LENGTH

   :type: int

.. data:: GL_PACK_SKIP_IMAGES

   :type: int

.. data:: GL_PACK_SKIP_PIXELS

   :type: int

.. data:: GL_PACK_SKIP_ROWS

   :type: int

.. data:: GL_PACK_SWAP_BYTES

   :type: int

.. data:: GL_PIXEL_PACK_BUFFER

   :type: int

.. data:: GL_PIXEL_PACK_BUFFER_BINDING

   :type: int

.. data:: GL_PIXEL_UNPACK_BUFFER

   :type: int

.. data:: GL_PIXEL_UNPACK_BUFFER_BINDING

   :type: int

.. data:: GL_POINT

   :type: int

.. data:: GL_POINTS

   :type: int

.. data:: GL_POINT_FADE_THRESHOLD_SIZE

   :type: int

.. data:: GL_POINT_SIZE

   :type: int

.. data:: GL_POINT_SPRITE_COORD_ORIGIN

   :type: int

.. data:: GL_POLYGON_MODE

   :type: int

.. data:: GL_POLYGON_OFFSET_FACTOR

   :type: int

.. data:: GL_POLYGON_OFFSET_FILL

   :type: int

.. data:: GL_POLYGON_OFFSET_LINE

   :type: int

.. data:: GL_POLYGON_OFFSET_POINT

   :type: int

.. data:: GL_POLYGON_OFFSET_UNITS

   :type: int

.. data:: GL_POLYGON_SMOOTH

   :type: int

.. data:: GL_POLYGON_SMOOTH_HINT

   :type: int

.. data:: GL_PRIMITIVES_GENERATED

   :type: int

.. data:: GL_PRIMITIVE_RESTART

   :type: int

.. data:: GL_PRIMITIVE_RESTART_INDEX

   :type: int

.. data:: GL_PROGRAM_POINT_SIZE

   :type: int

.. data:: GL_PROVOKING_VERTEX

   :type: int

.. data:: GL_PROXY_TEXTURE_1D

   :type: int

.. data:: GL_PROXY_TEXTURE_1D_ARRAY

   :type: int

.. data:: GL_PROXY_TEXTURE_2D

   :type: int

.. data:: GL_PROXY_TEXTURE_2D_ARRAY

   :type: int

.. data:: GL_PROXY_TEXTURE_2D_MULTISAMPLE

   :type: int

.. data:: GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY

   :type: int

.. data:: GL_PROXY_TEXTURE_3D

   :type: int

.. data:: GL_PROXY_TEXTURE_CUBE_MAP

   :type: int

.. data:: GL_PROXY_TEXTURE_RECTANGLE

   :type: int

.. data:: GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION

   :type: int

.. data:: GL_QUERY_BY_REGION_NO_WAIT

   :type: int

.. data:: GL_QUERY_BY_REGION_WAIT

   :type: int

.. data:: GL_QUERY_COUNTER_BITS

   :type: int

.. data:: GL_QUERY_NO_WAIT

   :type: int

.. data:: GL_QUERY_RESULT

   :type: int

.. data:: GL_QUERY_RESULT_AVAILABLE

   :type: int

.. data:: GL_QUERY_WAIT

   :type: int

.. data:: GL_R11F_G11F_B10F

   :type: int

.. data:: GL_R16

   :type: int

.. data:: GL_R16F

   :type: int

.. data:: GL_R16I

   :type: int

.. data:: GL_R16UI

   :type: int

.. data:: GL_R16_SNORM

   :type: int

.. data:: GL_R32F

   :type: int

.. data:: GL_R32I

   :type: int

.. data:: GL_R32UI

   :type: int

.. data:: GL_R3_G3_B2

   :type: int

.. data:: GL_R8

   :type: int

.. data:: GL_R8I

   :type: int

.. data:: GL_R8UI

   :type: int

.. data:: GL_R8_SNORM

   :type: int

.. data:: GL_RASTERIZER_DISCARD

   :type: int

.. data:: GL_READ_BUFFER

   :type: int

.. data:: GL_READ_FRAMEBUFFER

   :type: int

.. data:: GL_READ_FRAMEBUFFER_BINDING

   :type: int

.. data:: GL_READ_ONLY

   :type: int

.. data:: GL_READ_WRITE

   :type: int

.. data:: GL_RED

   :type: int

.. data:: GL_RED_INTEGER

   :type: int

.. data:: GL_RENDERBUFFER

   :type: int

.. data:: GL_RENDERBUFFER_ALPHA_SIZE

   :type: int

.. data:: GL_RENDERBUFFER_BINDING

   :type: int

.. data:: GL_RENDERBUFFER_BLUE_SIZE

   :type: int

.. data:: GL_RENDERBUFFER_DEPTH_SIZE

   :type: int

.. data:: GL_RENDERBUFFER_GREEN_SIZE

   :type: int

.. data:: GL_RENDERBUFFER_HEIGHT

   :type: int

.. data:: GL_RENDERBUFFER_INTERNAL_FORMAT

   :type: int

.. data:: GL_RENDERBUFFER_RED_SIZE

   :type: int

.. data:: GL_RENDERBUFFER_SAMPLES

   :type: int

.. data:: GL_RENDERBUFFER_STENCIL_SIZE

   :type: int

.. data:: GL_RENDERBUFFER_WIDTH

   :type: int

.. data:: GL_RENDERER

   :type: int

.. data:: GL_REPEAT

   :type: int

.. data:: GL_REPLACE

   :type: int

.. data:: GL_RG

   :type: int

.. data:: GL_RG16

   :type: int

.. data:: GL_RG16F

   :type: int

.. data:: GL_RG16I

   :type: int

.. data:: GL_RG16UI

   :type: int

.. data:: GL_RG16_SNORM

   :type: int

.. data:: GL_RG32F

   :type: int

.. data:: GL_RG32I

   :type: int

.. data:: GL_RG32UI

   :type: int

.. data:: GL_RG8

   :type: int

.. data:: GL_RG8I

   :type: int

.. data:: GL_RG8UI

   :type: int

.. data:: GL_RG8_SNORM

   :type: int

.. data:: GL_RGB

   :type: int

.. data:: GL_RGB10

   :type: int

.. data:: GL_RGB10_A2

   :type: int

.. data:: GL_RGB10_A2UI

   :type: int

.. data:: GL_RGB12

   :type: int

.. data:: GL_RGB16

   :type: int

.. data:: GL_RGB16F

   :type: int

.. data:: GL_RGB16I

   :type: int

.. data:: GL_RGB16UI

   :type: int

.. data:: GL_RGB16_SNORM

   :type: int

.. data:: GL_RGB32F

   :type: int

.. data:: GL_RGB32I

   :type: int

.. data:: GL_RGB32UI

   :type: int

.. data:: GL_RGB4

   :type: int

.. data:: GL_RGB5

   :type: int

.. data:: GL_RGB5_A1

   :type: int

.. data:: GL_RGB8

   :type: int

.. data:: GL_RGB8I

   :type: int

.. data:: GL_RGB8UI

   :type: int

.. data:: GL_RGB8_SNORM

   :type: int

.. data:: GL_RGB9_E5

   :type: int

.. data:: GL_RGBA

   :type: int

.. data:: GL_RGBA12

   :type: int

.. data:: GL_RGBA16

   :type: int

.. data:: GL_RGBA16F

   :type: int

.. data:: GL_RGBA16I

   :type: int

.. data:: GL_RGBA16UI

   :type: int

.. data:: GL_RGBA16_SNORM

   :type: int

.. data:: GL_RGBA2

   :type: int

.. data:: GL_RGBA32F

   :type: int

.. data:: GL_RGBA32I

   :type: int

.. data:: GL_RGBA32UI

   :type: int

.. data:: GL_RGBA4

   :type: int

.. data:: GL_RGBA8

   :type: int

.. data:: GL_RGBA8I

   :type: int

.. data:: GL_RGBA8UI

   :type: int

.. data:: GL_RGBA8_SNORM

   :type: int

.. data:: GL_RGBA_INTEGER

   :type: int

.. data:: GL_RGB_INTEGER

   :type: int

.. data:: GL_RG_INTEGER

   :type: int

.. data:: GL_RIGHT

   :type: int

.. data:: GL_SAMPLER_1D

   :type: int

.. data:: GL_SAMPLER_1D_ARRAY

   :type: int

.. data:: GL_SAMPLER_1D_ARRAY_SHADOW

   :type: int

.. data:: GL_SAMPLER_1D_SHADOW

   :type: int

.. data:: GL_SAMPLER_2D

   :type: int

.. data:: GL_SAMPLER_2D_ARRAY

   :type: int

.. data:: GL_SAMPLER_2D_ARRAY_SHADOW

   :type: int

.. data:: GL_SAMPLER_2D_MULTISAMPLE

   :type: int

.. data:: GL_SAMPLER_2D_MULTISAMPLE_ARRAY

   :type: int

.. data:: GL_SAMPLER_2D_RECT

   :type: int

.. data:: GL_SAMPLER_2D_RECT_SHADOW

   :type: int

.. data:: GL_SAMPLER_2D_SHADOW

   :type: int

.. data:: GL_SAMPLER_3D

   :type: int

.. data:: GL_SAMPLER_BINDING

   :type: int

.. data:: GL_SAMPLER_BUFFER

   :type: int

.. data:: GL_SAMPLER_CUBE

   :type: int

.. data:: GL_SAMPLER_CUBE_SHADOW

   :type: int

.. data:: GL_SAMPLES

   :type: int

.. data:: GL_SAMPLES_PASSED

   :type: int

.. data:: GL_SAMPLE_ALPHA_TO_COVERAGE

   :type: int

.. data:: GL_SAMPLE_ALPHA_TO_ONE

   :type: int

.. data:: GL_SAMPLE_BUFFERS

   :type: int

.. data:: GL_SAMPLE_COVERAGE

   :type: int

.. data:: GL_SAMPLE_COVERAGE_INVERT

   :type: int

.. data:: GL_SAMPLE_COVERAGE_VALUE

   :type: int

.. data:: GL_SAMPLE_MASK

   :type: int

.. data:: GL_SAMPLE_MASK_VALUE

   :type: int

.. data:: GL_SAMPLE_POSITION

   :type: int

.. data:: GL_SCISSOR_BOX

   :type: int

.. data:: GL_SCISSOR_TEST

   :type: int

.. data:: GL_SEPARATE_ATTRIBS

   :type: int

.. data:: GL_SET

   :type: int

.. data:: GL_SHADER_SOURCE_LENGTH

   :type: int

.. data:: GL_SHADER_TYPE

   :type: int

.. data:: GL_SHADING_LANGUAGE_VERSION

   :type: int

.. data:: GL_SHORT

   :type: int

.. data:: GL_SIGNALED

   :type: int

.. data:: GL_SIGNED_NORMALIZED

   :type: int

.. data:: GL_SMOOTH_LINE_WIDTH_GRANULARITY

   :type: int

.. data:: GL_SMOOTH_LINE_WIDTH_RANGE

   :type: int

.. data:: GL_SMOOTH_POINT_SIZE_GRANULARITY

   :type: int

.. data:: GL_SMOOTH_POINT_SIZE_RANGE

   :type: int

.. data:: GL_SRC1_COLOR

   :type: int

.. data:: GL_SRC_ALPHA

   :type: int

.. data:: GL_SRC_ALPHA_SATURATE

   :type: int

.. data:: GL_SRC_COLOR

   :type: int

.. data:: GL_SRGB

   :type: int

.. data:: GL_SRGB8

   :type: int

.. data:: GL_SRGB8_ALPHA8

   :type: int

.. data:: GL_SRGB_ALPHA

   :type: int

.. data:: GL_STATIC_COPY

   :type: int

.. data:: GL_STATIC_DRAW

   :type: int

.. data:: GL_STATIC_READ

   :type: int

.. data:: GL_STENCIL

   :type: int

.. data:: GL_STENCIL_ATTACHMENT

   :type: int

.. data:: GL_STENCIL_BACK_FAIL

   :type: int

.. data:: GL_STENCIL_BACK_FUNC

   :type: int

.. data:: GL_STENCIL_BACK_PASS_DEPTH_FAIL

   :type: int

.. data:: GL_STENCIL_BACK_PASS_DEPTH_PASS

   :type: int

.. data:: GL_STENCIL_BACK_REF

   :type: int

.. data:: GL_STENCIL_BACK_VALUE_MASK

   :type: int

.. data:: GL_STENCIL_BACK_WRITEMASK

   :type: int

.. data:: GL_STENCIL_BUFFER_BIT

   :type: int

.. data:: GL_STENCIL_CLEAR_VALUE

   :type: int

.. data:: GL_STENCIL_FAIL

   :type: int

.. data:: GL_STENCIL_FUNC

   :type: int

.. data:: GL_STENCIL_INDEX

   :type: int

.. data:: GL_STENCIL_INDEX1

   :type: int

.. data:: GL_STENCIL_INDEX16

   :type: int

.. data:: GL_STENCIL_INDEX4

   :type: int

.. data:: GL_STENCIL_INDEX8

   :type: int

.. data:: GL_STENCIL_PASS_DEPTH_FAIL

   :type: int

.. data:: GL_STENCIL_PASS_DEPTH_PASS

   :type: int

.. data:: GL_STENCIL_REF

   :type: int

.. data:: GL_STENCIL_TEST

   :type: int

.. data:: GL_STENCIL_VALUE_MASK

   :type: int

.. data:: GL_STENCIL_WRITEMASK

   :type: int

.. data:: GL_STEREO

   :type: int

.. data:: GL_STREAM_COPY

   :type: int

.. data:: GL_STREAM_DRAW

   :type: int

.. data:: GL_STREAM_READ

   :type: int

.. data:: GL_SUBPIXEL_BITS

   :type: int

.. data:: GL_SYNC_CONDITION

   :type: int

.. data:: GL_SYNC_FENCE

   :type: int

.. data:: GL_SYNC_FLAGS

   :type: int

.. data:: GL_SYNC_FLUSH_COMMANDS_BIT

   :type: int

.. data:: GL_SYNC_GPU_COMMANDS_COMPLETE

   :type: int

.. data:: GL_SYNC_STATUS

   :type: int

.. data:: GL_TEXTURE

   :type: int

.. data:: GL_TEXTURE0

   :type: int

.. data:: GL_TEXTURE1

   :type: int

.. data:: GL_TEXTURE10

   :type: int

.. data:: GL_TEXTURE11

   :type: int

.. data:: GL_TEXTURE12

   :type: int

.. data:: GL_TEXTURE13

   :type: int

.. data:: GL_TEXTURE14

   :type: int

.. data:: GL_TEXTURE15

   :type: int

.. data:: GL_TEXTURE16

   :type: int

.. data:: GL_TEXTURE17

   :type: int

.. data:: GL_TEXTURE18

   :type: int

.. data:: GL_TEXTURE19

   :type: int

.. data:: GL_TEXTURE2

   :type: int

.. data:: GL_TEXTURE20

   :type: int

.. data:: GL_TEXTURE21

   :type: int

.. data:: GL_TEXTURE22

   :type: int

.. data:: GL_TEXTURE23

   :type: int

.. data:: GL_TEXTURE24

   :type: int

.. data:: GL_TEXTURE25

   :type: int

.. data:: GL_TEXTURE26

   :type: int

.. data:: GL_TEXTURE27

   :type: int

.. data:: GL_TEXTURE28

   :type: int

.. data:: GL_TEXTURE29

   :type: int

.. data:: GL_TEXTURE3

   :type: int

.. data:: GL_TEXTURE30

   :type: int

.. data:: GL_TEXTURE31

   :type: int

.. data:: GL_TEXTURE4

   :type: int

.. data:: GL_TEXTURE5

   :type: int

.. data:: GL_TEXTURE6

   :type: int

.. data:: GL_TEXTURE7

   :type: int

.. data:: GL_TEXTURE8

   :type: int

.. data:: GL_TEXTURE9

   :type: int

.. data:: GL_TEXTURE_1D

   :type: int

.. data:: GL_TEXTURE_1D_ARRAY

   :type: int

.. data:: GL_TEXTURE_2D

   :type: int

.. data:: GL_TEXTURE_2D_ARRAY

   :type: int

.. data:: GL_TEXTURE_2D_MULTISAMPLE

   :type: int

.. data:: GL_TEXTURE_2D_MULTISAMPLE_ARRAY

   :type: int

.. data:: GL_TEXTURE_3D

   :type: int

.. data:: GL_TEXTURE_ALPHA_SIZE

   :type: int

.. data:: GL_TEXTURE_ALPHA_TYPE

   :type: int

.. data:: GL_TEXTURE_BASE_LEVEL

   :type: int

.. data:: GL_TEXTURE_BINDING_1D

   :type: int

.. data:: GL_TEXTURE_BINDING_1D_ARRAY

   :type: int

.. data:: GL_TEXTURE_BINDING_2D

   :type: int

.. data:: GL_TEXTURE_BINDING_2D_ARRAY

   :type: int

.. data:: GL_TEXTURE_BINDING_2D_MULTISAMPLE

   :type: int

.. data:: GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY

   :type: int

.. data:: GL_TEXTURE_BINDING_3D

   :type: int

.. data:: GL_TEXTURE_BINDING_BUFFER

   :type: int

.. data:: GL_TEXTURE_BINDING_CUBE_MAP

   :type: int

.. data:: GL_TEXTURE_BINDING_RECTANGLE

   :type: int

.. data:: GL_TEXTURE_BLUE_SIZE

   :type: int

.. data:: GL_TEXTURE_BLUE_TYPE

   :type: int

.. data:: GL_TEXTURE_BORDER_COLOR

   :type: int

.. data:: GL_TEXTURE_BUFFER

   :type: int

.. data:: GL_TEXTURE_BUFFER_DATA_STORE_BINDING

   :type: int

.. data:: GL_TEXTURE_COMPARE_FUNC

   :type: int

.. data:: GL_TEXTURE_COMPARE_MODE

   :type: int

.. data:: GL_TEXTURE_COMPRESSED

   :type: int

.. data:: GL_TEXTURE_COMPRESSED_IMAGE_SIZE

   :type: int

.. data:: GL_TEXTURE_COMPRESSION_HINT

   :type: int

.. data:: GL_TEXTURE_CUBE_MAP

   :type: int

.. data:: GL_TEXTURE_CUBE_MAP_NEGATIVE_X

   :type: int

.. data:: GL_TEXTURE_CUBE_MAP_NEGATIVE_Y

   :type: int

.. data:: GL_TEXTURE_CUBE_MAP_NEGATIVE_Z

   :type: int

.. data:: GL_TEXTURE_CUBE_MAP_POSITIVE_X

   :type: int

.. data:: GL_TEXTURE_CUBE_MAP_POSITIVE_Y

   :type: int

.. data:: GL_TEXTURE_CUBE_MAP_POSITIVE_Z

   :type: int

.. data:: GL_TEXTURE_CUBE_MAP_SEAMLESS

   :type: int

.. data:: GL_TEXTURE_DEPTH

   :type: int

.. data:: GL_TEXTURE_DEPTH_SIZE

   :type: int

.. data:: GL_TEXTURE_DEPTH_TYPE

   :type: int

.. data:: GL_TEXTURE_FIXED_SAMPLE_LOCATIONS

   :type: int

.. data:: GL_TEXTURE_GREEN_SIZE

   :type: int

.. data:: GL_TEXTURE_GREEN_TYPE

   :type: int

.. data:: GL_TEXTURE_HEIGHT

   :type: int

.. data:: GL_TEXTURE_INTERNAL_FORMAT

   :type: int

.. data:: GL_TEXTURE_LOD_BIAS

   :type: int

.. data:: GL_TEXTURE_MAG_FILTER

   :type: int

.. data:: GL_TEXTURE_MAX_LEVEL

   :type: int

.. data:: GL_TEXTURE_MAX_LOD

   :type: int

.. data:: GL_TEXTURE_MIN_FILTER

   :type: int

.. data:: GL_TEXTURE_MIN_LOD

   :type: int

.. data:: GL_TEXTURE_RECTANGLE

   :type: int

.. data:: GL_TEXTURE_RED_SIZE

   :type: int

.. data:: GL_TEXTURE_RED_TYPE

   :type: int

.. data:: GL_TEXTURE_SAMPLES

   :type: int

.. data:: GL_TEXTURE_SHARED_SIZE

   :type: int

.. data:: GL_TEXTURE_STENCIL_SIZE

   :type: int

.. data:: GL_TEXTURE_SWIZZLE_A

   :type: int

.. data:: GL_TEXTURE_SWIZZLE_B

   :type: int

.. data:: GL_TEXTURE_SWIZZLE_G

   :type: int

.. data:: GL_TEXTURE_SWIZZLE_R

   :type: int

.. data:: GL_TEXTURE_SWIZZLE_RGBA

   :type: int

.. data:: GL_TEXTURE_WIDTH

   :type: int

.. data:: GL_TEXTURE_WRAP_R

   :type: int

.. data:: GL_TEXTURE_WRAP_S

   :type: int

.. data:: GL_TEXTURE_WRAP_T

   :type: int

.. data:: GL_TIMEOUT_EXPIRED

   :type: int

.. data:: GL_TIMEOUT_IGNORED

   :type: int

.. data:: GL_TIMESTAMP

   :type: int

.. data:: GL_TIME_ELAPSED

   :type: int

.. data:: GL_TRANSFORM_FEEDBACK_BUFFER

   :type: int

.. data:: GL_TRANSFORM_FEEDBACK_BUFFER_BINDING

   :type: int

.. data:: GL_TRANSFORM_FEEDBACK_BUFFER_MODE

   :type: int

.. data:: GL_TRANSFORM_FEEDBACK_BUFFER_SIZE

   :type: int

.. data:: GL_TRANSFORM_FEEDBACK_BUFFER_START

   :type: int

.. data:: GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN

   :type: int

.. data:: GL_TRANSFORM_FEEDBACK_VARYINGS

   :type: int

.. data:: GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH

   :type: int

.. data:: GL_TRIANGLES

   :type: int

.. data:: GL_TRIANGLES_ADJACENCY

   :type: int

.. data:: GL_TRIANGLE_FAN

   :type: int

.. data:: GL_TRIANGLE_STRIP

   :type: int

.. data:: GL_TRIANGLE_STRIP_ADJACENCY

   :type: int

.. data:: GL_TRUE

   :type: int

.. data:: GL_UNIFORM_ARRAY_STRIDE

   :type: int

.. data:: GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS

   :type: int

.. data:: GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES

   :type: int

.. data:: GL_UNIFORM_BLOCK_BINDING

   :type: int

.. data:: GL_UNIFORM_BLOCK_DATA_SIZE

   :type: int

.. data:: GL_UNIFORM_BLOCK_INDEX

   :type: int

.. data:: GL_UNIFORM_BLOCK_NAME_LENGTH

   :type: int

.. data:: GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER

   :type: int

.. data:: GL_UNIFORM_BLOCK_REFERENCED_BY_GEOMETRY_SHADER

   :type: int

.. data:: GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER

   :type: int

.. data:: GL_UNIFORM_BUFFER

   :type: int

.. data:: GL_UNIFORM_BUFFER_BINDING

   :type: int

.. data:: GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT

   :type: int

.. data:: GL_UNIFORM_BUFFER_SIZE

   :type: int

.. data:: GL_UNIFORM_BUFFER_START

   :type: int

.. data:: GL_UNIFORM_IS_ROW_MAJOR

   :type: int

.. data:: GL_UNIFORM_MATRIX_STRIDE

   :type: int

.. data:: GL_UNIFORM_NAME_LENGTH

   :type: int

.. data:: GL_UNIFORM_OFFSET

   :type: int

.. data:: GL_UNIFORM_SIZE

   :type: int

.. data:: GL_UNIFORM_TYPE

   :type: int

.. data:: GL_UNPACK_ALIGNMENT

   :type: int

.. data:: GL_UNPACK_IMAGE_HEIGHT

   :type: int

.. data:: GL_UNPACK_LSB_FIRST

   :type: int

.. data:: GL_UNPACK_ROW_LENGTH

   :type: int

.. data:: GL_UNPACK_SKIP_IMAGES

   :type: int

.. data:: GL_UNPACK_SKIP_PIXELS

   :type: int

.. data:: GL_UNPACK_SKIP_ROWS

   :type: int

.. data:: GL_UNPACK_SWAP_BYTES

   :type: int

.. data:: GL_UNSIGNALED

   :type: int

.. data:: GL_UNSIGNED_BYTE

   :type: int

.. data:: GL_UNSIGNED_BYTE_2_3_3_REV

   :type: int

.. data:: GL_UNSIGNED_BYTE_3_3_2

   :type: int

.. data:: GL_UNSIGNED_INT

   :type: int

.. data:: GL_UNSIGNED_INT_10F_11F_11F_REV

   :type: int

.. data:: GL_UNSIGNED_INT_10_10_10_2

   :type: int

.. data:: GL_UNSIGNED_INT_24_8

   :type: int

.. data:: GL_UNSIGNED_INT_2_10_10_10_REV

   :type: int

.. data:: GL_UNSIGNED_INT_5_9_9_9_REV

   :type: int

.. data:: GL_UNSIGNED_INT_8_8_8_8

   :type: int

.. data:: GL_UNSIGNED_INT_8_8_8_8_REV

   :type: int

.. data:: GL_UNSIGNED_INT_SAMPLER_1D

   :type: int

.. data:: GL_UNSIGNED_INT_SAMPLER_1D_ARRAY

   :type: int

.. data:: GL_UNSIGNED_INT_SAMPLER_2D

   :type: int

.. data:: GL_UNSIGNED_INT_SAMPLER_2D_ARRAY

   :type: int

.. data:: GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE

   :type: int

.. data:: GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY

   :type: int

.. data:: GL_UNSIGNED_INT_SAMPLER_2D_RECT

   :type: int

.. data:: GL_UNSIGNED_INT_SAMPLER_3D

   :type: int

.. data:: GL_UNSIGNED_INT_SAMPLER_BUFFER

   :type: int

.. data:: GL_UNSIGNED_INT_SAMPLER_CUBE

   :type: int

.. data:: GL_UNSIGNED_INT_VEC2

   :type: int

.. data:: GL_UNSIGNED_INT_VEC3

   :type: int

.. data:: GL_UNSIGNED_INT_VEC4

   :type: int

.. data:: GL_UNSIGNED_NORMALIZED

   :type: int

.. data:: GL_UNSIGNED_SHORT

   :type: int

.. data:: GL_UNSIGNED_SHORT_1_5_5_5_REV

   :type: int

.. data:: GL_UNSIGNED_SHORT_4_4_4_4

   :type: int

.. data:: GL_UNSIGNED_SHORT_4_4_4_4_REV

   :type: int

.. data:: GL_UNSIGNED_SHORT_5_5_5_1

   :type: int

.. data:: GL_UNSIGNED_SHORT_5_6_5

   :type: int

.. data:: GL_UNSIGNED_SHORT_5_6_5_REV

   :type: int

.. data:: GL_UPPER_LEFT

   :type: int

.. data:: GL_VALIDATE_STATUS

   :type: int

.. data:: GL_VENDOR

   :type: int

.. data:: GL_VERSION

   :type: int

.. data:: GL_VERTEX_ARRAY_BINDING

   :type: int

.. data:: GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING

   :type: int

.. data:: GL_VERTEX_ATTRIB_ARRAY_DIVISOR

   :type: int

.. data:: GL_VERTEX_ATTRIB_ARRAY_ENABLED

   :type: int

.. data:: GL_VERTEX_ATTRIB_ARRAY_INTEGER

   :type: int

.. data:: GL_VERTEX_ATTRIB_ARRAY_NORMALIZED

   :type: int

.. data:: GL_VERTEX_ATTRIB_ARRAY_POINTER

   :type: int

.. data:: GL_VERTEX_ATTRIB_ARRAY_SIZE

   :type: int

.. data:: GL_VERTEX_ATTRIB_ARRAY_STRIDE

   :type: int

.. data:: GL_VERTEX_ATTRIB_ARRAY_TYPE

   :type: int

.. data:: GL_VERTEX_PROGRAM_POINT_SIZE

   :type: int

.. data:: GL_VERTEX_SHADER

   :type: int

.. data:: GL_VIEWPORT

   :type: int

.. data:: GL_WAIT_FAILED

   :type: int

.. data:: GL_WRITE_ONLY

   :type: int

.. data:: GL_XOR

   :type: int

.. data:: GL_ZERO

   :type: int

.. function:: glDeleteBuffers(n, buffers):

    Delete named buffer objects

   .. seealso:: `OpenGL Docs <https://khronos.org/registry/OpenGL-Refpages/gl4/html/glDeleteBuffers.xhtml>`__

   :type n: int
   :arg n: Specifies the number of buffer objects to be deleted.
   :type buffer: :class:`bgl.Buffer` int buffer.
   :arg buffer: Specifies an array of buffer objects to be deleted.
